@@ -1,13 +1,18 @@
 import pytest
+from fake_kubernetes_client import FakeDynamicClient
 from ocp_resources.image_image_openshift_io import Image
 
 
 @pytest.mark.incremental
 class TestImage:
     @pytest.fixture(scope="class")
-    def image(self, fake_client):
+    def client(self):
+        return FakeDynamicClient()
+
+    @pytest.fixture(scope="class")
+    def image(self, client):
         return Image(
-            client=fake_client,
+            client=client,
             name="test-image",
         )
 
